# coding: utf-8

# flake8: noqa
"""
    vpc

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into model package
from volcenginesdkvpc.models.add_bandwidth_package_ip_request import AddBandwidthPackageIpRequest
from volcenginesdkvpc.models.add_bandwidth_package_ip_response import AddBandwidthPackageIpResponse
from volcenginesdkvpc.models.allocate_eip_address_request import AllocateEipAddressRequest
from volcenginesdkvpc.models.allocate_eip_address_response import AllocateEipAddressResponse
from volcenginesdkvpc.models.assign_private_ip_addresses_request import AssignPrivateIpAddressesRequest
from volcenginesdkvpc.models.assign_private_ip_addresses_response import AssignPrivateIpAddressesResponse
from volcenginesdkvpc.models.associate_cen_for_describe_vpc_attributes_output import AssociateCenForDescribeVpcAttributesOutput
from volcenginesdkvpc.models.associate_cen_for_describe_vpcs_output import AssociateCenForDescribeVpcsOutput
from volcenginesdkvpc.models.associate_eip_address_request import AssociateEipAddressRequest
from volcenginesdkvpc.models.associate_eip_address_response import AssociateEipAddressResponse
from volcenginesdkvpc.models.associate_ha_vip_request import AssociateHaVipRequest
from volcenginesdkvpc.models.associate_ha_vip_response import AssociateHaVipResponse
from volcenginesdkvpc.models.associate_network_acl_request import AssociateNetworkAclRequest
from volcenginesdkvpc.models.associate_network_acl_response import AssociateNetworkAclResponse
from volcenginesdkvpc.models.associate_route_table_request import AssociateRouteTableRequest
from volcenginesdkvpc.models.associate_route_table_response import AssociateRouteTableResponse
from volcenginesdkvpc.models.associated_elastic_ip_for_describe_network_interface_attributes_output import AssociatedElasticIpForDescribeNetworkInterfaceAttributesOutput
from volcenginesdkvpc.models.associated_elastic_ip_for_describe_network_interfaces_output import AssociatedElasticIpForDescribeNetworkInterfacesOutput
from volcenginesdkvpc.models.attach_network_interface_request import AttachNetworkInterfaceRequest
from volcenginesdkvpc.models.attach_network_interface_response import AttachNetworkInterfaceResponse
from volcenginesdkvpc.models.authorize_security_group_egress_request import AuthorizeSecurityGroupEgressRequest
from volcenginesdkvpc.models.authorize_security_group_egress_response import AuthorizeSecurityGroupEgressResponse
from volcenginesdkvpc.models.authorize_security_group_ingress_request import AuthorizeSecurityGroupIngressRequest
from volcenginesdkvpc.models.authorize_security_group_ingress_response import AuthorizeSecurityGroupIngressResponse
from volcenginesdkvpc.models.bandwidth_package_for_describe_bandwidth_packages_output import BandwidthPackageForDescribeBandwidthPackagesOutput
from volcenginesdkvpc.models.create_bandwidth_package_request import CreateBandwidthPackageRequest
from volcenginesdkvpc.models.create_bandwidth_package_response import CreateBandwidthPackageResponse
from volcenginesdkvpc.models.create_ha_vip_request import CreateHaVipRequest
from volcenginesdkvpc.models.create_ha_vip_response import CreateHaVipResponse
from volcenginesdkvpc.models.create_network_acl_request import CreateNetworkAclRequest
from volcenginesdkvpc.models.create_network_acl_response import CreateNetworkAclResponse
from volcenginesdkvpc.models.create_network_interface_request import CreateNetworkInterfaceRequest
from volcenginesdkvpc.models.create_network_interface_response import CreateNetworkInterfaceResponse
from volcenginesdkvpc.models.create_route_entry_request import CreateRouteEntryRequest
from volcenginesdkvpc.models.create_route_entry_response import CreateRouteEntryResponse
from volcenginesdkvpc.models.create_route_table_request import CreateRouteTableRequest
from volcenginesdkvpc.models.create_route_table_response import CreateRouteTableResponse
from volcenginesdkvpc.models.create_security_group_request import CreateSecurityGroupRequest
from volcenginesdkvpc.models.create_security_group_response import CreateSecurityGroupResponse
from volcenginesdkvpc.models.create_subnet_request import CreateSubnetRequest
from volcenginesdkvpc.models.create_subnet_response import CreateSubnetResponse
from volcenginesdkvpc.models.create_vpc_request import CreateVpcRequest
from volcenginesdkvpc.models.create_vpc_response import CreateVpcResponse
from volcenginesdkvpc.models.delete_bandwidth_package_request import DeleteBandwidthPackageRequest
from volcenginesdkvpc.models.delete_bandwidth_package_response import DeleteBandwidthPackageResponse
from volcenginesdkvpc.models.delete_ha_vip_request import DeleteHaVipRequest
from volcenginesdkvpc.models.delete_ha_vip_response import DeleteHaVipResponse
from volcenginesdkvpc.models.delete_network_acl_request import DeleteNetworkAclRequest
from volcenginesdkvpc.models.delete_network_acl_response import DeleteNetworkAclResponse
from volcenginesdkvpc.models.delete_network_interface_request import DeleteNetworkInterfaceRequest
from volcenginesdkvpc.models.delete_network_interface_response import DeleteNetworkInterfaceResponse
from volcenginesdkvpc.models.delete_route_entry_request import DeleteRouteEntryRequest
from volcenginesdkvpc.models.delete_route_entry_response import DeleteRouteEntryResponse
from volcenginesdkvpc.models.delete_route_table_request import DeleteRouteTableRequest
from volcenginesdkvpc.models.delete_route_table_response import DeleteRouteTableResponse
from volcenginesdkvpc.models.delete_security_group_request import DeleteSecurityGroupRequest
from volcenginesdkvpc.models.delete_security_group_response import DeleteSecurityGroupResponse
from volcenginesdkvpc.models.delete_subnet_request import DeleteSubnetRequest
from volcenginesdkvpc.models.delete_subnet_response import DeleteSubnetResponse
from volcenginesdkvpc.models.delete_vpc_request import DeleteVpcRequest
from volcenginesdkvpc.models.delete_vpc_response import DeleteVpcResponse
from volcenginesdkvpc.models.describe_bandwidth_packages_request import DescribeBandwidthPackagesRequest
from volcenginesdkvpc.models.describe_bandwidth_packages_response import DescribeBandwidthPackagesResponse
from volcenginesdkvpc.models.describe_eip_address_attributes_request import DescribeEipAddressAttributesRequest
from volcenginesdkvpc.models.describe_eip_address_attributes_response import DescribeEipAddressAttributesResponse
from volcenginesdkvpc.models.describe_eip_addresses_request import DescribeEipAddressesRequest
from volcenginesdkvpc.models.describe_eip_addresses_response import DescribeEipAddressesResponse
from volcenginesdkvpc.models.describe_ha_vips_request import DescribeHaVipsRequest
from volcenginesdkvpc.models.describe_ha_vips_response import DescribeHaVipsResponse
from volcenginesdkvpc.models.describe_network_acl_attributes_request import DescribeNetworkAclAttributesRequest
from volcenginesdkvpc.models.describe_network_acl_attributes_response import DescribeNetworkAclAttributesResponse
from volcenginesdkvpc.models.describe_network_acls_request import DescribeNetworkAclsRequest
from volcenginesdkvpc.models.describe_network_acls_response import DescribeNetworkAclsResponse
from volcenginesdkvpc.models.describe_network_interface_attributes_request import DescribeNetworkInterfaceAttributesRequest
from volcenginesdkvpc.models.describe_network_interface_attributes_response import DescribeNetworkInterfaceAttributesResponse
from volcenginesdkvpc.models.describe_network_interfaces_request import DescribeNetworkInterfacesRequest
from volcenginesdkvpc.models.describe_network_interfaces_response import DescribeNetworkInterfacesResponse
from volcenginesdkvpc.models.describe_route_entry_list_request import DescribeRouteEntryListRequest
from volcenginesdkvpc.models.describe_route_entry_list_response import DescribeRouteEntryListResponse
from volcenginesdkvpc.models.describe_route_table_list_request import DescribeRouteTableListRequest
from volcenginesdkvpc.models.describe_route_table_list_response import DescribeRouteTableListResponse
from volcenginesdkvpc.models.describe_security_group_attributes_request import DescribeSecurityGroupAttributesRequest
from volcenginesdkvpc.models.describe_security_group_attributes_response import DescribeSecurityGroupAttributesResponse
from volcenginesdkvpc.models.describe_security_groups_request import DescribeSecurityGroupsRequest
from volcenginesdkvpc.models.describe_security_groups_response import DescribeSecurityGroupsResponse
from volcenginesdkvpc.models.describe_subnet_attributes_request import DescribeSubnetAttributesRequest
from volcenginesdkvpc.models.describe_subnet_attributes_response import DescribeSubnetAttributesResponse
from volcenginesdkvpc.models.describe_subnets_request import DescribeSubnetsRequest
from volcenginesdkvpc.models.describe_subnets_response import DescribeSubnetsResponse
from volcenginesdkvpc.models.describe_vpc_attributes_request import DescribeVpcAttributesRequest
from volcenginesdkvpc.models.describe_vpc_attributes_response import DescribeVpcAttributesResponse
from volcenginesdkvpc.models.describe_vpcs_request import DescribeVpcsRequest
from volcenginesdkvpc.models.describe_vpcs_response import DescribeVpcsResponse
from volcenginesdkvpc.models.detach_network_interface_request import DetachNetworkInterfaceRequest
from volcenginesdkvpc.models.detach_network_interface_response import DetachNetworkInterfaceResponse
from volcenginesdkvpc.models.disassociate_eip_address_request import DisassociateEipAddressRequest
from volcenginesdkvpc.models.disassociate_eip_address_response import DisassociateEipAddressResponse
from volcenginesdkvpc.models.disassociate_ha_vip_request import DisassociateHaVipRequest
from volcenginesdkvpc.models.disassociate_ha_vip_response import DisassociateHaVipResponse
from volcenginesdkvpc.models.disassociate_network_acl_request import DisassociateNetworkAclRequest
from volcenginesdkvpc.models.disassociate_network_acl_response import DisassociateNetworkAclResponse
from volcenginesdkvpc.models.disassociate_route_table_request import DisassociateRouteTableRequest
from volcenginesdkvpc.models.disassociate_route_table_response import DisassociateRouteTableResponse
from volcenginesdkvpc.models.egress_acl_entry_for_describe_network_acl_attributes_output import EgressAclEntryForDescribeNetworkAclAttributesOutput
from volcenginesdkvpc.models.egress_acl_entry_for_describe_network_acls_output import EgressAclEntryForDescribeNetworkAclsOutput
from volcenginesdkvpc.models.egress_acl_entry_for_update_network_acl_entries_input import EgressAclEntryForUpdateNetworkAclEntriesInput
from volcenginesdkvpc.models.eip_address_for_describe_bandwidth_packages_output import EipAddressForDescribeBandwidthPackagesOutput
from volcenginesdkvpc.models.eip_address_for_describe_eip_addresses_output import EipAddressForDescribeEipAddressesOutput
from volcenginesdkvpc.models.ha_vip_for_describe_ha_vips_output import HaVipForDescribeHaVipsOutput
from volcenginesdkvpc.models.ingress_acl_entry_for_describe_network_acl_attributes_output import IngressAclEntryForDescribeNetworkAclAttributesOutput
from volcenginesdkvpc.models.ingress_acl_entry_for_describe_network_acls_output import IngressAclEntryForDescribeNetworkAclsOutput
from volcenginesdkvpc.models.ingress_acl_entry_for_update_network_acl_entries_input import IngressAclEntryForUpdateNetworkAclEntriesInput
from volcenginesdkvpc.models.list_tags_for_resources_request import ListTagsForResourcesRequest
from volcenginesdkvpc.models.list_tags_for_resources_response import ListTagsForResourcesResponse
from volcenginesdkvpc.models.modify_bandwidth_package_attributes_request import ModifyBandwidthPackageAttributesRequest
from volcenginesdkvpc.models.modify_bandwidth_package_attributes_response import ModifyBandwidthPackageAttributesResponse
from volcenginesdkvpc.models.modify_bandwidth_package_spec_request import ModifyBandwidthPackageSpecRequest
from volcenginesdkvpc.models.modify_bandwidth_package_spec_response import ModifyBandwidthPackageSpecResponse
from volcenginesdkvpc.models.modify_eip_address_attributes_request import ModifyEipAddressAttributesRequest
from volcenginesdkvpc.models.modify_eip_address_attributes_response import ModifyEipAddressAttributesResponse
from volcenginesdkvpc.models.modify_ha_vip_attributes_request import ModifyHaVipAttributesRequest
from volcenginesdkvpc.models.modify_ha_vip_attributes_response import ModifyHaVipAttributesResponse
from volcenginesdkvpc.models.modify_network_acl_attributes_request import ModifyNetworkAclAttributesRequest
from volcenginesdkvpc.models.modify_network_acl_attributes_response import ModifyNetworkAclAttributesResponse
from volcenginesdkvpc.models.modify_network_interface_attributes_request import ModifyNetworkInterfaceAttributesRequest
from volcenginesdkvpc.models.modify_network_interface_attributes_response import ModifyNetworkInterfaceAttributesResponse
from volcenginesdkvpc.models.modify_route_entry_request import ModifyRouteEntryRequest
from volcenginesdkvpc.models.modify_route_entry_response import ModifyRouteEntryResponse
from volcenginesdkvpc.models.modify_route_table_attributes_request import ModifyRouteTableAttributesRequest
from volcenginesdkvpc.models.modify_route_table_attributes_response import ModifyRouteTableAttributesResponse
from volcenginesdkvpc.models.modify_security_group_attributes_request import ModifySecurityGroupAttributesRequest
from volcenginesdkvpc.models.modify_security_group_attributes_response import ModifySecurityGroupAttributesResponse
from volcenginesdkvpc.models.modify_security_group_rule_descriptions_egress_request import ModifySecurityGroupRuleDescriptionsEgressRequest
from volcenginesdkvpc.models.modify_security_group_rule_descriptions_egress_response import ModifySecurityGroupRuleDescriptionsEgressResponse
from volcenginesdkvpc.models.modify_security_group_rule_descriptions_ingress_request import ModifySecurityGroupRuleDescriptionsIngressRequest
from volcenginesdkvpc.models.modify_security_group_rule_descriptions_ingress_response import ModifySecurityGroupRuleDescriptionsIngressResponse
from volcenginesdkvpc.models.modify_subnet_attributes_request import ModifySubnetAttributesRequest
from volcenginesdkvpc.models.modify_subnet_attributes_response import ModifySubnetAttributesResponse
from volcenginesdkvpc.models.modify_vpc_attributes_request import ModifyVpcAttributesRequest
from volcenginesdkvpc.models.modify_vpc_attributes_response import ModifyVpcAttributesResponse
from volcenginesdkvpc.models.network_acl_attribute_for_describe_network_acl_attributes_output import NetworkAclAttributeForDescribeNetworkAclAttributesOutput
from volcenginesdkvpc.models.network_acl_for_describe_network_acls_output import NetworkAclForDescribeNetworkAclsOutput
from volcenginesdkvpc.models.network_interface_set_for_describe_network_interfaces_output import NetworkInterfaceSetForDescribeNetworkInterfacesOutput
from volcenginesdkvpc.models.permission_for_describe_security_group_attributes_output import PermissionForDescribeSecurityGroupAttributesOutput
from volcenginesdkvpc.models.private_ip_set_for_describe_network_interface_attributes_output import PrivateIpSetForDescribeNetworkInterfaceAttributesOutput
from volcenginesdkvpc.models.private_ip_set_for_describe_network_interfaces_output import PrivateIpSetForDescribeNetworkInterfacesOutput
from volcenginesdkvpc.models.private_ip_sets_for_describe_network_interface_attributes_output import PrivateIpSetsForDescribeNetworkInterfaceAttributesOutput
from volcenginesdkvpc.models.private_ip_sets_for_describe_network_interfaces_output import PrivateIpSetsForDescribeNetworkInterfacesOutput
from volcenginesdkvpc.models.release_eip_address_request import ReleaseEipAddressRequest
from volcenginesdkvpc.models.release_eip_address_response import ReleaseEipAddressResponse
from volcenginesdkvpc.models.remove_bandwidth_package_ip_request import RemoveBandwidthPackageIpRequest
from volcenginesdkvpc.models.remove_bandwidth_package_ip_response import RemoveBandwidthPackageIpResponse
from volcenginesdkvpc.models.resource_for_associate_network_acl_input import ResourceForAssociateNetworkAclInput
from volcenginesdkvpc.models.resource_for_describe_network_acl_attributes_output import ResourceForDescribeNetworkAclAttributesOutput
from volcenginesdkvpc.models.resource_for_describe_network_acls_output import ResourceForDescribeNetworkAclsOutput
from volcenginesdkvpc.models.resource_for_disassociate_network_acl_input import ResourceForDisassociateNetworkAclInput
from volcenginesdkvpc.models.resource_tag_for_list_tags_for_resources_output import ResourceTagForListTagsForResourcesOutput
from volcenginesdkvpc.models.revoke_security_group_egress_request import RevokeSecurityGroupEgressRequest
from volcenginesdkvpc.models.revoke_security_group_egress_response import RevokeSecurityGroupEgressResponse
from volcenginesdkvpc.models.revoke_security_group_ingress_request import RevokeSecurityGroupIngressRequest
from volcenginesdkvpc.models.revoke_security_group_ingress_response import RevokeSecurityGroupIngressResponse
from volcenginesdkvpc.models.route_entry_for_describe_route_entry_list_output import RouteEntryForDescribeRouteEntryListOutput
from volcenginesdkvpc.models.route_table_for_describe_subnet_attributes_output import RouteTableForDescribeSubnetAttributesOutput
from volcenginesdkvpc.models.route_table_for_describe_subnets_output import RouteTableForDescribeSubnetsOutput
from volcenginesdkvpc.models.router_table_list_for_describe_route_table_list_output import RouterTableListForDescribeRouteTableListOutput
from volcenginesdkvpc.models.security_group_for_describe_security_groups_output import SecurityGroupForDescribeSecurityGroupsOutput
from volcenginesdkvpc.models.subnet_for_describe_subnets_output import SubnetForDescribeSubnetsOutput
from volcenginesdkvpc.models.tag_filter_for_describe_bandwidth_packages_input import TagFilterForDescribeBandwidthPackagesInput
from volcenginesdkvpc.models.tag_filter_for_describe_eip_addresses_input import TagFilterForDescribeEipAddressesInput
from volcenginesdkvpc.models.tag_filter_for_describe_network_interfaces_input import TagFilterForDescribeNetworkInterfacesInput
from volcenginesdkvpc.models.tag_filter_for_describe_security_groups_input import TagFilterForDescribeSecurityGroupsInput
from volcenginesdkvpc.models.tag_filter_for_describe_vpcs_input import TagFilterForDescribeVpcsInput
from volcenginesdkvpc.models.tag_filter_for_list_tags_for_resources_input import TagFilterForListTagsForResourcesInput
from volcenginesdkvpc.models.tag_for_allocate_eip_address_input import TagForAllocateEipAddressInput
from volcenginesdkvpc.models.tag_for_create_bandwidth_package_input import TagForCreateBandwidthPackageInput
from volcenginesdkvpc.models.tag_for_create_network_interface_input import TagForCreateNetworkInterfaceInput
from volcenginesdkvpc.models.tag_for_create_security_group_input import TagForCreateSecurityGroupInput
from volcenginesdkvpc.models.tag_for_create_vpc_input import TagForCreateVpcInput
from volcenginesdkvpc.models.tag_for_describe_bandwidth_packages_output import TagForDescribeBandwidthPackagesOutput
from volcenginesdkvpc.models.tag_for_describe_eip_address_attributes_output import TagForDescribeEipAddressAttributesOutput
from volcenginesdkvpc.models.tag_for_describe_eip_addresses_output import TagForDescribeEipAddressesOutput
from volcenginesdkvpc.models.tag_for_describe_network_interface_attributes_output import TagForDescribeNetworkInterfaceAttributesOutput
from volcenginesdkvpc.models.tag_for_describe_network_interfaces_output import TagForDescribeNetworkInterfacesOutput
from volcenginesdkvpc.models.tag_for_describe_security_group_attributes_output import TagForDescribeSecurityGroupAttributesOutput
from volcenginesdkvpc.models.tag_for_describe_security_groups_output import TagForDescribeSecurityGroupsOutput
from volcenginesdkvpc.models.tag_for_describe_vpc_attributes_output import TagForDescribeVpcAttributesOutput
from volcenginesdkvpc.models.tag_for_describe_vpcs_output import TagForDescribeVpcsOutput
from volcenginesdkvpc.models.tag_for_tag_resources_input import TagForTagResourcesInput
from volcenginesdkvpc.models.tag_resources_request import TagResourcesRequest
from volcenginesdkvpc.models.tag_resources_response import TagResourcesResponse
from volcenginesdkvpc.models.unassign_private_ip_addresses_request import UnassignPrivateIpAddressesRequest
from volcenginesdkvpc.models.unassign_private_ip_addresses_response import UnassignPrivateIpAddressesResponse
from volcenginesdkvpc.models.untag_resources_request import UntagResourcesRequest
from volcenginesdkvpc.models.untag_resources_response import UntagResourcesResponse
from volcenginesdkvpc.models.update_network_acl_entries_request import UpdateNetworkAclEntriesRequest
from volcenginesdkvpc.models.update_network_acl_entries_response import UpdateNetworkAclEntriesResponse
from volcenginesdkvpc.models.vpc_for_describe_vpcs_output import VpcForDescribeVpcsOutput



# coding: utf-8

"""
    vke

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class PodsConfigForListClustersOutput(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'flannel_config': 'FlannelConfigForListClustersOutput',
        'pod_network_mode': 'str',
        'vpc_cni_config': 'VpcCniConfigForListClustersOutput'
    }

    attribute_map = {
        'flannel_config': 'FlannelConfig',
        'pod_network_mode': 'PodNetworkMode',
        'vpc_cni_config': 'VpcCniConfig'
    }

    def __init__(self, flannel_config=None, pod_network_mode=None, vpc_cni_config=None, _configuration=None):  # noqa: E501
        """PodsConfigForListClustersOutput - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._flannel_config = None
        self._pod_network_mode = None
        self._vpc_cni_config = None
        self.discriminator = None

        if flannel_config is not None:
            self.flannel_config = flannel_config
        if pod_network_mode is not None:
            self.pod_network_mode = pod_network_mode
        if vpc_cni_config is not None:
            self.vpc_cni_config = vpc_cni_config

    @property
    def flannel_config(self):
        """Gets the flannel_config of this PodsConfigForListClustersOutput.  # noqa: E501


        :return: The flannel_config of this PodsConfigForListClustersOutput.  # noqa: E501
        :rtype: FlannelConfigForListClustersOutput
        """
        return self._flannel_config

    @flannel_config.setter
    def flannel_config(self, flannel_config):
        """Sets the flannel_config of this PodsConfigForListClustersOutput.


        :param flannel_config: The flannel_config of this PodsConfigForListClustersOutput.  # noqa: E501
        :type: FlannelConfigForListClustersOutput
        """

        self._flannel_config = flannel_config

    @property
    def pod_network_mode(self):
        """Gets the pod_network_mode of this PodsConfigForListClustersOutput.  # noqa: E501


        :return: The pod_network_mode of this PodsConfigForListClustersOutput.  # noqa: E501
        :rtype: str
        """
        return self._pod_network_mode

    @pod_network_mode.setter
    def pod_network_mode(self, pod_network_mode):
        """Sets the pod_network_mode of this PodsConfigForListClustersOutput.


        :param pod_network_mode: The pod_network_mode of this PodsConfigForListClustersOutput.  # noqa: E501
        :type: str
        """

        self._pod_network_mode = pod_network_mode

    @property
    def vpc_cni_config(self):
        """Gets the vpc_cni_config of this PodsConfigForListClustersOutput.  # noqa: E501


        :return: The vpc_cni_config of this PodsConfigForListClustersOutput.  # noqa: E501
        :rtype: VpcCniConfigForListClustersOutput
        """
        return self._vpc_cni_config

    @vpc_cni_config.setter
    def vpc_cni_config(self, vpc_cni_config):
        """Sets the vpc_cni_config of this PodsConfigForListClustersOutput.


        :param vpc_cni_config: The vpc_cni_config of this PodsConfigForListClustersOutput.  # noqa: E501
        :type: VpcCniConfigForListClustersOutput
        """

        self._vpc_cni_config = vpc_cni_config

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PodsConfigForListClustersOutput, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PodsConfigForListClustersOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PodsConfigForListClustersOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    ecs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class SystemEventForDescribeSystemEventsOutput(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'created_at': 'str',
        'id': 'str',
        'operated_end_at': 'str',
        'operated_start_at': 'str',
        'resource_id': 'str',
        'status': 'str',
        'type': 'str',
        'updated_at': 'str'
    }

    attribute_map = {
        'created_at': 'CreatedAt',
        'id': 'Id',
        'operated_end_at': 'OperatedEndAt',
        'operated_start_at': 'OperatedStartAt',
        'resource_id': 'ResourceId',
        'status': 'Status',
        'type': 'Type',
        'updated_at': 'UpdatedAt'
    }

    def __init__(self, created_at=None, id=None, operated_end_at=None, operated_start_at=None, resource_id=None, status=None, type=None, updated_at=None, _configuration=None):  # noqa: E501
        """SystemEventForDescribeSystemEventsOutput - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._created_at = None
        self._id = None
        self._operated_end_at = None
        self._operated_start_at = None
        self._resource_id = None
        self._status = None
        self._type = None
        self._updated_at = None
        self.discriminator = None

        if created_at is not None:
            self.created_at = created_at
        if id is not None:
            self.id = id
        if operated_end_at is not None:
            self.operated_end_at = operated_end_at
        if operated_start_at is not None:
            self.operated_start_at = operated_start_at
        if resource_id is not None:
            self.resource_id = resource_id
        if status is not None:
            self.status = status
        if type is not None:
            self.type = type
        if updated_at is not None:
            self.updated_at = updated_at

    @property
    def created_at(self):
        """Gets the created_at of this SystemEventForDescribeSystemEventsOutput.  # noqa: E501


        :return: The created_at of this SystemEventForDescribeSystemEventsOutput.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this SystemEventForDescribeSystemEventsOutput.


        :param created_at: The created_at of this SystemEventForDescribeSystemEventsOutput.  # noqa: E501
        :type: str
        """

        self._created_at = created_at

    @property
    def id(self):
        """Gets the id of this SystemEventForDescribeSystemEventsOutput.  # noqa: E501


        :return: The id of this SystemEventForDescribeSystemEventsOutput.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this SystemEventForDescribeSystemEventsOutput.


        :param id: The id of this SystemEventForDescribeSystemEventsOutput.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def operated_end_at(self):
        """Gets the operated_end_at of this SystemEventForDescribeSystemEventsOutput.  # noqa: E501


        :return: The operated_end_at of this SystemEventForDescribeSystemEventsOutput.  # noqa: E501
        :rtype: str
        """
        return self._operated_end_at

    @operated_end_at.setter
    def operated_end_at(self, operated_end_at):
        """Sets the operated_end_at of this SystemEventForDescribeSystemEventsOutput.


        :param operated_end_at: The operated_end_at of this SystemEventForDescribeSystemEventsOutput.  # noqa: E501
        :type: str
        """

        self._operated_end_at = operated_end_at

    @property
    def operated_start_at(self):
        """Gets the operated_start_at of this SystemEventForDescribeSystemEventsOutput.  # noqa: E501


        :return: The operated_start_at of this SystemEventForDescribeSystemEventsOutput.  # noqa: E501
        :rtype: str
        """
        return self._operated_start_at

    @operated_start_at.setter
    def operated_start_at(self, operated_start_at):
        """Sets the operated_start_at of this SystemEventForDescribeSystemEventsOutput.


        :param operated_start_at: The operated_start_at of this SystemEventForDescribeSystemEventsOutput.  # noqa: E501
        :type: str
        """

        self._operated_start_at = operated_start_at

    @property
    def resource_id(self):
        """Gets the resource_id of this SystemEventForDescribeSystemEventsOutput.  # noqa: E501


        :return: The resource_id of this SystemEventForDescribeSystemEventsOutput.  # noqa: E501
        :rtype: str
        """
        return self._resource_id

    @resource_id.setter
    def resource_id(self, resource_id):
        """Sets the resource_id of this SystemEventForDescribeSystemEventsOutput.


        :param resource_id: The resource_id of this SystemEventForDescribeSystemEventsOutput.  # noqa: E501
        :type: str
        """

        self._resource_id = resource_id

    @property
    def status(self):
        """Gets the status of this SystemEventForDescribeSystemEventsOutput.  # noqa: E501


        :return: The status of this SystemEventForDescribeSystemEventsOutput.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this SystemEventForDescribeSystemEventsOutput.


        :param status: The status of this SystemEventForDescribeSystemEventsOutput.  # noqa: E501
        :type: str
        """
        allowed_values = ["UnknownStatus", "Executing", "Succeeded", "Failed", "Inquiring", "Scheduled", "Rejected"]  # noqa: E501
        if (self._configuration.client_side_validation and
                status not in allowed_values):
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def type(self):
        """Gets the type of this SystemEventForDescribeSystemEventsOutput.  # noqa: E501


        :return: The type of this SystemEventForDescribeSystemEventsOutput.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this SystemEventForDescribeSystemEventsOutput.


        :param type: The type of this SystemEventForDescribeSystemEventsOutput.  # noqa: E501
        :type: str
        """
        allowed_values = ["UnknownType", "SystemFailure_Stop", "SystemFailure_Reboot", "SystemFailure_PleaseCheck", "DiskError_Redeploy", "HDDBadSector_Redeploy", "GpuError_Redeploy", "SystemMaintenance_Redeploy", "SystemFailure_Redeploy", "CreateInstance", "RunInstance", "StopInstance", "DeleteInstance", "SpotInstanceInterruption_Delete", "AccountUnbalanced_Stop", "AccountUnbalanced_Delete", "InstanceChargeType_Change", "InstanceConfiguration_Change", "FileSystemReadOnly_Change", "RebootInstance", "InstanceFailure"]  # noqa: E501
        if (self._configuration.client_side_validation and
                type not in allowed_values):
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def updated_at(self):
        """Gets the updated_at of this SystemEventForDescribeSystemEventsOutput.  # noqa: E501


        :return: The updated_at of this SystemEventForDescribeSystemEventsOutput.  # noqa: E501
        :rtype: str
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this SystemEventForDescribeSystemEventsOutput.


        :param updated_at: The updated_at of this SystemEventForDescribeSystemEventsOutput.  # noqa: E501
        :type: str
        """

        self._updated_at = updated_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SystemEventForDescribeSystemEventsOutput, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SystemEventForDescribeSystemEventsOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SystemEventForDescribeSystemEventsOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    clb

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class CertificateForDescribeCertificatesOutput(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'certificate_id': 'str',
        'certificate_name': 'str',
        'create_time': 'str',
        'description': 'str',
        'domain_name': 'str',
        'expired_at': 'str',
        'listeners': 'list[str]',
        'project_name': 'str'
    }

    attribute_map = {
        'certificate_id': 'CertificateId',
        'certificate_name': 'CertificateName',
        'create_time': 'CreateTime',
        'description': 'Description',
        'domain_name': 'DomainName',
        'expired_at': 'ExpiredAt',
        'listeners': 'Listeners',
        'project_name': 'ProjectName'
    }

    def __init__(self, certificate_id=None, certificate_name=None, create_time=None, description=None, domain_name=None, expired_at=None, listeners=None, project_name=None, _configuration=None):  # noqa: E501
        """CertificateForDescribeCertificatesOutput - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._certificate_id = None
        self._certificate_name = None
        self._create_time = None
        self._description = None
        self._domain_name = None
        self._expired_at = None
        self._listeners = None
        self._project_name = None
        self.discriminator = None

        if certificate_id is not None:
            self.certificate_id = certificate_id
        if certificate_name is not None:
            self.certificate_name = certificate_name
        if create_time is not None:
            self.create_time = create_time
        if description is not None:
            self.description = description
        if domain_name is not None:
            self.domain_name = domain_name
        if expired_at is not None:
            self.expired_at = expired_at
        if listeners is not None:
            self.listeners = listeners
        if project_name is not None:
            self.project_name = project_name

    @property
    def certificate_id(self):
        """Gets the certificate_id of this CertificateForDescribeCertificatesOutput.  # noqa: E501


        :return: The certificate_id of this CertificateForDescribeCertificatesOutput.  # noqa: E501
        :rtype: str
        """
        return self._certificate_id

    @certificate_id.setter
    def certificate_id(self, certificate_id):
        """Sets the certificate_id of this CertificateForDescribeCertificatesOutput.


        :param certificate_id: The certificate_id of this CertificateForDescribeCertificatesOutput.  # noqa: E501
        :type: str
        """

        self._certificate_id = certificate_id

    @property
    def certificate_name(self):
        """Gets the certificate_name of this CertificateForDescribeCertificatesOutput.  # noqa: E501


        :return: The certificate_name of this CertificateForDescribeCertificatesOutput.  # noqa: E501
        :rtype: str
        """
        return self._certificate_name

    @certificate_name.setter
    def certificate_name(self, certificate_name):
        """Sets the certificate_name of this CertificateForDescribeCertificatesOutput.


        :param certificate_name: The certificate_name of this CertificateForDescribeCertificatesOutput.  # noqa: E501
        :type: str
        """

        self._certificate_name = certificate_name

    @property
    def create_time(self):
        """Gets the create_time of this CertificateForDescribeCertificatesOutput.  # noqa: E501


        :return: The create_time of this CertificateForDescribeCertificatesOutput.  # noqa: E501
        :rtype: str
        """
        return self._create_time

    @create_time.setter
    def create_time(self, create_time):
        """Sets the create_time of this CertificateForDescribeCertificatesOutput.


        :param create_time: The create_time of this CertificateForDescribeCertificatesOutput.  # noqa: E501
        :type: str
        """

        self._create_time = create_time

    @property
    def description(self):
        """Gets the description of this CertificateForDescribeCertificatesOutput.  # noqa: E501


        :return: The description of this CertificateForDescribeCertificatesOutput.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this CertificateForDescribeCertificatesOutput.


        :param description: The description of this CertificateForDescribeCertificatesOutput.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def domain_name(self):
        """Gets the domain_name of this CertificateForDescribeCertificatesOutput.  # noqa: E501


        :return: The domain_name of this CertificateForDescribeCertificatesOutput.  # noqa: E501
        :rtype: str
        """
        return self._domain_name

    @domain_name.setter
    def domain_name(self, domain_name):
        """Sets the domain_name of this CertificateForDescribeCertificatesOutput.


        :param domain_name: The domain_name of this CertificateForDescribeCertificatesOutput.  # noqa: E501
        :type: str
        """

        self._domain_name = domain_name

    @property
    def expired_at(self):
        """Gets the expired_at of this CertificateForDescribeCertificatesOutput.  # noqa: E501


        :return: The expired_at of this CertificateForDescribeCertificatesOutput.  # noqa: E501
        :rtype: str
        """
        return self._expired_at

    @expired_at.setter
    def expired_at(self, expired_at):
        """Sets the expired_at of this CertificateForDescribeCertificatesOutput.


        :param expired_at: The expired_at of this CertificateForDescribeCertificatesOutput.  # noqa: E501
        :type: str
        """

        self._expired_at = expired_at

    @property
    def listeners(self):
        """Gets the listeners of this CertificateForDescribeCertificatesOutput.  # noqa: E501


        :return: The listeners of this CertificateForDescribeCertificatesOutput.  # noqa: E501
        :rtype: list[str]
        """
        return self._listeners

    @listeners.setter
    def listeners(self, listeners):
        """Sets the listeners of this CertificateForDescribeCertificatesOutput.


        :param listeners: The listeners of this CertificateForDescribeCertificatesOutput.  # noqa: E501
        :type: list[str]
        """

        self._listeners = listeners

    @property
    def project_name(self):
        """Gets the project_name of this CertificateForDescribeCertificatesOutput.  # noqa: E501


        :return: The project_name of this CertificateForDescribeCertificatesOutput.  # noqa: E501
        :rtype: str
        """
        return self._project_name

    @project_name.setter
    def project_name(self, project_name):
        """Sets the project_name of this CertificateForDescribeCertificatesOutput.


        :param project_name: The project_name of this CertificateForDescribeCertificatesOutput.  # noqa: E501
        :type: str
        """

        self._project_name = project_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CertificateForDescribeCertificatesOutput, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CertificateForDescribeCertificatesOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CertificateForDescribeCertificatesOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    rds_mysql

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class CreateDBInstanceRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'auto_renew': 'bool',
        'charge_type': 'str',
        'db_engine': 'str',
        'db_engine_version': 'str',
        'instance_name': 'str',
        'instance_spec_name': 'str',
        'instance_type': 'str',
        'number': 'int',
        'parameter_template_id': 'str',
        'prepaid_period': 'str',
        'project_name': 'str',
        'storage_space_gb': 'int',
        'storage_type': 'str',
        'subnet_id': 'str',
        'super_account_name': 'str',
        'super_account_password': 'str',
        'used_time': 'int',
        'vpc_id': 'str',
        'zone': 'str'
    }

    attribute_map = {
        'auto_renew': 'AutoRenew',
        'charge_type': 'ChargeType',
        'db_engine': 'DBEngine',
        'db_engine_version': 'DBEngineVersion',
        'instance_name': 'InstanceName',
        'instance_spec_name': 'InstanceSpecName',
        'instance_type': 'InstanceType',
        'number': 'Number',
        'parameter_template_id': 'ParameterTemplateId',
        'prepaid_period': 'PrepaidPeriod',
        'project_name': 'ProjectName',
        'storage_space_gb': 'StorageSpaceGB',
        'storage_type': 'StorageType',
        'subnet_id': 'SubnetId',
        'super_account_name': 'SuperAccountName',
        'super_account_password': 'SuperAccountPassword',
        'used_time': 'UsedTime',
        'vpc_id': 'VpcID',
        'zone': 'Zone'
    }

    def __init__(self, auto_renew=None, charge_type=None, db_engine=None, db_engine_version=None, instance_name=None, instance_spec_name=None, instance_type=None, number=None, parameter_template_id=None, prepaid_period=None, project_name=None, storage_space_gb=None, storage_type=None, subnet_id=None, super_account_name=None, super_account_password=None, used_time=None, vpc_id=None, zone=None, _configuration=None):  # noqa: E501
        """CreateDBInstanceRequest - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._auto_renew = None
        self._charge_type = None
        self._db_engine = None
        self._db_engine_version = None
        self._instance_name = None
        self._instance_spec_name = None
        self._instance_type = None
        self._number = None
        self._parameter_template_id = None
        self._prepaid_period = None
        self._project_name = None
        self._storage_space_gb = None
        self._storage_type = None
        self._subnet_id = None
        self._super_account_name = None
        self._super_account_password = None
        self._used_time = None
        self._vpc_id = None
        self._zone = None
        self.discriminator = None

        if auto_renew is not None:
            self.auto_renew = auto_renew
        if charge_type is not None:
            self.charge_type = charge_type
        if db_engine is not None:
            self.db_engine = db_engine
        if db_engine_version is not None:
            self.db_engine_version = db_engine_version
        if instance_name is not None:
            self.instance_name = instance_name
        if instance_spec_name is not None:
            self.instance_spec_name = instance_spec_name
        if instance_type is not None:
            self.instance_type = instance_type
        if number is not None:
            self.number = number
        if parameter_template_id is not None:
            self.parameter_template_id = parameter_template_id
        if prepaid_period is not None:
            self.prepaid_period = prepaid_period
        if project_name is not None:
            self.project_name = project_name
        self.storage_space_gb = storage_space_gb
        if storage_type is not None:
            self.storage_type = storage_type
        if subnet_id is not None:
            self.subnet_id = subnet_id
        if super_account_name is not None:
            self.super_account_name = super_account_name
        if super_account_password is not None:
            self.super_account_password = super_account_password
        if used_time is not None:
            self.used_time = used_time
        if vpc_id is not None:
            self.vpc_id = vpc_id
        self.zone = zone

    @property
    def auto_renew(self):
        """Gets the auto_renew of this CreateDBInstanceRequest.  # noqa: E501


        :return: The auto_renew of this CreateDBInstanceRequest.  # noqa: E501
        :rtype: bool
        """
        return self._auto_renew

    @auto_renew.setter
    def auto_renew(self, auto_renew):
        """Sets the auto_renew of this CreateDBInstanceRequest.


        :param auto_renew: The auto_renew of this CreateDBInstanceRequest.  # noqa: E501
        :type: bool
        """

        self._auto_renew = auto_renew

    @property
    def charge_type(self):
        """Gets the charge_type of this CreateDBInstanceRequest.  # noqa: E501


        :return: The charge_type of this CreateDBInstanceRequest.  # noqa: E501
        :rtype: str
        """
        return self._charge_type

    @charge_type.setter
    def charge_type(self, charge_type):
        """Sets the charge_type of this CreateDBInstanceRequest.


        :param charge_type: The charge_type of this CreateDBInstanceRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["NotEnabled", "PostPaid", "Prepaid"]  # noqa: E501
        if (self._configuration.client_side_validation and
                charge_type not in allowed_values):
            raise ValueError(
                "Invalid value for `charge_type` ({0}), must be one of {1}"  # noqa: E501
                .format(charge_type, allowed_values)
            )

        self._charge_type = charge_type

    @property
    def db_engine(self):
        """Gets the db_engine of this CreateDBInstanceRequest.  # noqa: E501


        :return: The db_engine of this CreateDBInstanceRequest.  # noqa: E501
        :rtype: str
        """
        return self._db_engine

    @db_engine.setter
    def db_engine(self, db_engine):
        """Sets the db_engine of this CreateDBInstanceRequest.


        :param db_engine: The db_engine of this CreateDBInstanceRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["MySQL"]  # noqa: E501
        if (self._configuration.client_side_validation and
                db_engine not in allowed_values):
            raise ValueError(
                "Invalid value for `db_engine` ({0}), must be one of {1}"  # noqa: E501
                .format(db_engine, allowed_values)
            )

        self._db_engine = db_engine

    @property
    def db_engine_version(self):
        """Gets the db_engine_version of this CreateDBInstanceRequest.  # noqa: E501


        :return: The db_engine_version of this CreateDBInstanceRequest.  # noqa: E501
        :rtype: str
        """
        return self._db_engine_version

    @db_engine_version.setter
    def db_engine_version(self, db_engine_version):
        """Sets the db_engine_version of this CreateDBInstanceRequest.


        :param db_engine_version: The db_engine_version of this CreateDBInstanceRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["MySQL_8_0", "MySQL_Community_5_7"]  # noqa: E501
        if (self._configuration.client_side_validation and
                db_engine_version not in allowed_values):
            raise ValueError(
                "Invalid value for `db_engine_version` ({0}), must be one of {1}"  # noqa: E501
                .format(db_engine_version, allowed_values)
            )

        self._db_engine_version = db_engine_version

    @property
    def instance_name(self):
        """Gets the instance_name of this CreateDBInstanceRequest.  # noqa: E501


        :return: The instance_name of this CreateDBInstanceRequest.  # noqa: E501
        :rtype: str
        """
        return self._instance_name

    @instance_name.setter
    def instance_name(self, instance_name):
        """Sets the instance_name of this CreateDBInstanceRequest.


        :param instance_name: The instance_name of this CreateDBInstanceRequest.  # noqa: E501
        :type: str
        """

        self._instance_name = instance_name

    @property
    def instance_spec_name(self):
        """Gets the instance_spec_name of this CreateDBInstanceRequest.  # noqa: E501


        :return: The instance_spec_name of this CreateDBInstanceRequest.  # noqa: E501
        :rtype: str
        """
        return self._instance_spec_name

    @instance_spec_name.setter
    def instance_spec_name(self, instance_spec_name):
        """Sets the instance_spec_name of this CreateDBInstanceRequest.


        :param instance_spec_name: The instance_spec_name of this CreateDBInstanceRequest.  # noqa: E501
        :type: str
        """

        self._instance_spec_name = instance_spec_name

    @property
    def instance_type(self):
        """Gets the instance_type of this CreateDBInstanceRequest.  # noqa: E501


        :return: The instance_type of this CreateDBInstanceRequest.  # noqa: E501
        :rtype: str
        """
        return self._instance_type

    @instance_type.setter
    def instance_type(self, instance_type):
        """Sets the instance_type of this CreateDBInstanceRequest.


        :param instance_type: The instance_type of this CreateDBInstanceRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["HA"]  # noqa: E501
        if (self._configuration.client_side_validation and
                instance_type not in allowed_values):
            raise ValueError(
                "Invalid value for `instance_type` ({0}), must be one of {1}"  # noqa: E501
                .format(instance_type, allowed_values)
            )

        self._instance_type = instance_type

    @property
    def number(self):
        """Gets the number of this CreateDBInstanceRequest.  # noqa: E501


        :return: The number of this CreateDBInstanceRequest.  # noqa: E501
        :rtype: int
        """
        return self._number

    @number.setter
    def number(self, number):
        """Sets the number of this CreateDBInstanceRequest.


        :param number: The number of this CreateDBInstanceRequest.  # noqa: E501
        :type: int
        """

        self._number = number

    @property
    def parameter_template_id(self):
        """Gets the parameter_template_id of this CreateDBInstanceRequest.  # noqa: E501


        :return: The parameter_template_id of this CreateDBInstanceRequest.  # noqa: E501
        :rtype: str
        """
        return self._parameter_template_id

    @parameter_template_id.setter
    def parameter_template_id(self, parameter_template_id):
        """Sets the parameter_template_id of this CreateDBInstanceRequest.


        :param parameter_template_id: The parameter_template_id of this CreateDBInstanceRequest.  # noqa: E501
        :type: str
        """

        self._parameter_template_id = parameter_template_id

    @property
    def prepaid_period(self):
        """Gets the prepaid_period of this CreateDBInstanceRequest.  # noqa: E501


        :return: The prepaid_period of this CreateDBInstanceRequest.  # noqa: E501
        :rtype: str
        """
        return self._prepaid_period

    @prepaid_period.setter
    def prepaid_period(self, prepaid_period):
        """Sets the prepaid_period of this CreateDBInstanceRequest.


        :param prepaid_period: The prepaid_period of this CreateDBInstanceRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["Month", "Year"]  # noqa: E501
        if (self._configuration.client_side_validation and
                prepaid_period not in allowed_values):
            raise ValueError(
                "Invalid value for `prepaid_period` ({0}), must be one of {1}"  # noqa: E501
                .format(prepaid_period, allowed_values)
            )

        self._prepaid_period = prepaid_period

    @property
    def project_name(self):
        """Gets the project_name of this CreateDBInstanceRequest.  # noqa: E501


        :return: The project_name of this CreateDBInstanceRequest.  # noqa: E501
        :rtype: str
        """
        return self._project_name

    @project_name.setter
    def project_name(self, project_name):
        """Sets the project_name of this CreateDBInstanceRequest.


        :param project_name: The project_name of this CreateDBInstanceRequest.  # noqa: E501
        :type: str
        """

        self._project_name = project_name

    @property
    def storage_space_gb(self):
        """Gets the storage_space_gb of this CreateDBInstanceRequest.  # noqa: E501


        :return: The storage_space_gb of this CreateDBInstanceRequest.  # noqa: E501
        :rtype: int
        """
        return self._storage_space_gb

    @storage_space_gb.setter
    def storage_space_gb(self, storage_space_gb):
        """Sets the storage_space_gb of this CreateDBInstanceRequest.


        :param storage_space_gb: The storage_space_gb of this CreateDBInstanceRequest.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and storage_space_gb is None:
            raise ValueError("Invalid value for `storage_space_gb`, must not be `None`")  # noqa: E501

        self._storage_space_gb = storage_space_gb

    @property
    def storage_type(self):
        """Gets the storage_type of this CreateDBInstanceRequest.  # noqa: E501


        :return: The storage_type of this CreateDBInstanceRequest.  # noqa: E501
        :rtype: str
        """
        return self._storage_type

    @storage_type.setter
    def storage_type(self, storage_type):
        """Sets the storage_type of this CreateDBInstanceRequest.


        :param storage_type: The storage_type of this CreateDBInstanceRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["CloudStorage", "ESSDPL1", "ESSDPL2", "LocalSSD"]  # noqa: E501
        if (self._configuration.client_side_validation and
                storage_type not in allowed_values):
            raise ValueError(
                "Invalid value for `storage_type` ({0}), must be one of {1}"  # noqa: E501
                .format(storage_type, allowed_values)
            )

        self._storage_type = storage_type

    @property
    def subnet_id(self):
        """Gets the subnet_id of this CreateDBInstanceRequest.  # noqa: E501


        :return: The subnet_id of this CreateDBInstanceRequest.  # noqa: E501
        :rtype: str
        """
        return self._subnet_id

    @subnet_id.setter
    def subnet_id(self, subnet_id):
        """Sets the subnet_id of this CreateDBInstanceRequest.


        :param subnet_id: The subnet_id of this CreateDBInstanceRequest.  # noqa: E501
        :type: str
        """

        self._subnet_id = subnet_id

    @property
    def super_account_name(self):
        """Gets the super_account_name of this CreateDBInstanceRequest.  # noqa: E501


        :return: The super_account_name of this CreateDBInstanceRequest.  # noqa: E501
        :rtype: str
        """
        return self._super_account_name

    @super_account_name.setter
    def super_account_name(self, super_account_name):
        """Sets the super_account_name of this CreateDBInstanceRequest.


        :param super_account_name: The super_account_name of this CreateDBInstanceRequest.  # noqa: E501
        :type: str
        """

        self._super_account_name = super_account_name

    @property
    def super_account_password(self):
        """Gets the super_account_password of this CreateDBInstanceRequest.  # noqa: E501


        :return: The super_account_password of this CreateDBInstanceRequest.  # noqa: E501
        :rtype: str
        """
        return self._super_account_password

    @super_account_password.setter
    def super_account_password(self, super_account_password):
        """Sets the super_account_password of this CreateDBInstanceRequest.


        :param super_account_password: The super_account_password of this CreateDBInstanceRequest.  # noqa: E501
        :type: str
        """

        self._super_account_password = super_account_password

    @property
    def used_time(self):
        """Gets the used_time of this CreateDBInstanceRequest.  # noqa: E501


        :return: The used_time of this CreateDBInstanceRequest.  # noqa: E501
        :rtype: int
        """
        return self._used_time

    @used_time.setter
    def used_time(self, used_time):
        """Sets the used_time of this CreateDBInstanceRequest.


        :param used_time: The used_time of this CreateDBInstanceRequest.  # noqa: E501
        :type: int
        """

        self._used_time = used_time

    @property
    def vpc_id(self):
        """Gets the vpc_id of this CreateDBInstanceRequest.  # noqa: E501


        :return: The vpc_id of this CreateDBInstanceRequest.  # noqa: E501
        :rtype: str
        """
        return self._vpc_id

    @vpc_id.setter
    def vpc_id(self, vpc_id):
        """Sets the vpc_id of this CreateDBInstanceRequest.


        :param vpc_id: The vpc_id of this CreateDBInstanceRequest.  # noqa: E501
        :type: str
        """

        self._vpc_id = vpc_id

    @property
    def zone(self):
        """Gets the zone of this CreateDBInstanceRequest.  # noqa: E501


        :return: The zone of this CreateDBInstanceRequest.  # noqa: E501
        :rtype: str
        """
        return self._zone

    @zone.setter
    def zone(self, zone):
        """Sets the zone of this CreateDBInstanceRequest.


        :param zone: The zone of this CreateDBInstanceRequest.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and zone is None:
            raise ValueError("Invalid value for `zone`, must not be `None`")  # noqa: E501

        self._zone = zone

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CreateDBInstanceRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateDBInstanceRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateDBInstanceRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    rds_mysql

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class RecoveryDBInstanceRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'auto_renew': 'bool',
        'backup_id': 'str',
        'charge_type': 'str',
        'instance_id': 'str',
        'instance_name': 'str',
        'instance_spec_name': 'str',
        'prepaid_period': 'str',
        'recovery_type': 'str',
        'restore_time': 'str',
        'storage_space_gb': 'int',
        'storage_type': 'str',
        'used_time': 'int',
        'vpc_id': 'str'
    }

    attribute_map = {
        'auto_renew': 'AutoRenew',
        'backup_id': 'BackupId',
        'charge_type': 'ChargeType',
        'instance_id': 'InstanceId',
        'instance_name': 'InstanceName',
        'instance_spec_name': 'InstanceSpecName',
        'prepaid_period': 'PrepaidPeriod',
        'recovery_type': 'RecoveryType',
        'restore_time': 'RestoreTime',
        'storage_space_gb': 'StorageSpaceGB',
        'storage_type': 'StorageType',
        'used_time': 'UsedTime',
        'vpc_id': 'VpcID'
    }

    def __init__(self, auto_renew=None, backup_id=None, charge_type=None, instance_id=None, instance_name=None, instance_spec_name=None, prepaid_period=None, recovery_type=None, restore_time=None, storage_space_gb=None, storage_type=None, used_time=None, vpc_id=None, _configuration=None):  # noqa: E501
        """RecoveryDBInstanceRequest - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._auto_renew = None
        self._backup_id = None
        self._charge_type = None
        self._instance_id = None
        self._instance_name = None
        self._instance_spec_name = None
        self._prepaid_period = None
        self._recovery_type = None
        self._restore_time = None
        self._storage_space_gb = None
        self._storage_type = None
        self._used_time = None
        self._vpc_id = None
        self.discriminator = None

        if auto_renew is not None:
            self.auto_renew = auto_renew
        if backup_id is not None:
            self.backup_id = backup_id
        if charge_type is not None:
            self.charge_type = charge_type
        self.instance_id = instance_id
        if instance_name is not None:
            self.instance_name = instance_name
        if instance_spec_name is not None:
            self.instance_spec_name = instance_spec_name
        if prepaid_period is not None:
            self.prepaid_period = prepaid_period
        if recovery_type is not None:
            self.recovery_type = recovery_type
        if restore_time is not None:
            self.restore_time = restore_time
        if storage_space_gb is not None:
            self.storage_space_gb = storage_space_gb
        if storage_type is not None:
            self.storage_type = storage_type
        if used_time is not None:
            self.used_time = used_time
        if vpc_id is not None:
            self.vpc_id = vpc_id

    @property
    def auto_renew(self):
        """Gets the auto_renew of this RecoveryDBInstanceRequest.  # noqa: E501


        :return: The auto_renew of this RecoveryDBInstanceRequest.  # noqa: E501
        :rtype: bool
        """
        return self._auto_renew

    @auto_renew.setter
    def auto_renew(self, auto_renew):
        """Sets the auto_renew of this RecoveryDBInstanceRequest.


        :param auto_renew: The auto_renew of this RecoveryDBInstanceRequest.  # noqa: E501
        :type: bool
        """

        self._auto_renew = auto_renew

    @property
    def backup_id(self):
        """Gets the backup_id of this RecoveryDBInstanceRequest.  # noqa: E501


        :return: The backup_id of this RecoveryDBInstanceRequest.  # noqa: E501
        :rtype: str
        """
        return self._backup_id

    @backup_id.setter
    def backup_id(self, backup_id):
        """Sets the backup_id of this RecoveryDBInstanceRequest.


        :param backup_id: The backup_id of this RecoveryDBInstanceRequest.  # noqa: E501
        :type: str
        """

        self._backup_id = backup_id

    @property
    def charge_type(self):
        """Gets the charge_type of this RecoveryDBInstanceRequest.  # noqa: E501


        :return: The charge_type of this RecoveryDBInstanceRequest.  # noqa: E501
        :rtype: str
        """
        return self._charge_type

    @charge_type.setter
    def charge_type(self, charge_type):
        """Sets the charge_type of this RecoveryDBInstanceRequest.


        :param charge_type: The charge_type of this RecoveryDBInstanceRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["NotEnabled", "PostPaid", "Prepaid"]  # noqa: E501
        if (self._configuration.client_side_validation and
                charge_type not in allowed_values):
            raise ValueError(
                "Invalid value for `charge_type` ({0}), must be one of {1}"  # noqa: E501
                .format(charge_type, allowed_values)
            )

        self._charge_type = charge_type

    @property
    def instance_id(self):
        """Gets the instance_id of this RecoveryDBInstanceRequest.  # noqa: E501


        :return: The instance_id of this RecoveryDBInstanceRequest.  # noqa: E501
        :rtype: str
        """
        return self._instance_id

    @instance_id.setter
    def instance_id(self, instance_id):
        """Sets the instance_id of this RecoveryDBInstanceRequest.


        :param instance_id: The instance_id of this RecoveryDBInstanceRequest.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and instance_id is None:
            raise ValueError("Invalid value for `instance_id`, must not be `None`")  # noqa: E501

        self._instance_id = instance_id

    @property
    def instance_name(self):
        """Gets the instance_name of this RecoveryDBInstanceRequest.  # noqa: E501


        :return: The instance_name of this RecoveryDBInstanceRequest.  # noqa: E501
        :rtype: str
        """
        return self._instance_name

    @instance_name.setter
    def instance_name(self, instance_name):
        """Sets the instance_name of this RecoveryDBInstanceRequest.


        :param instance_name: The instance_name of this RecoveryDBInstanceRequest.  # noqa: E501
        :type: str
        """

        self._instance_name = instance_name

    @property
    def instance_spec_name(self):
        """Gets the instance_spec_name of this RecoveryDBInstanceRequest.  # noqa: E501


        :return: The instance_spec_name of this RecoveryDBInstanceRequest.  # noqa: E501
        :rtype: str
        """
        return self._instance_spec_name

    @instance_spec_name.setter
    def instance_spec_name(self, instance_spec_name):
        """Sets the instance_spec_name of this RecoveryDBInstanceRequest.


        :param instance_spec_name: The instance_spec_name of this RecoveryDBInstanceRequest.  # noqa: E501
        :type: str
        """

        self._instance_spec_name = instance_spec_name

    @property
    def prepaid_period(self):
        """Gets the prepaid_period of this RecoveryDBInstanceRequest.  # noqa: E501


        :return: The prepaid_period of this RecoveryDBInstanceRequest.  # noqa: E501
        :rtype: str
        """
        return self._prepaid_period

    @prepaid_period.setter
    def prepaid_period(self, prepaid_period):
        """Sets the prepaid_period of this RecoveryDBInstanceRequest.


        :param prepaid_period: The prepaid_period of this RecoveryDBInstanceRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["Month", "Year"]  # noqa: E501
        if (self._configuration.client_side_validation and
                prepaid_period not in allowed_values):
            raise ValueError(
                "Invalid value for `prepaid_period` ({0}), must be one of {1}"  # noqa: E501
                .format(prepaid_period, allowed_values)
            )

        self._prepaid_period = prepaid_period

    @property
    def recovery_type(self):
        """Gets the recovery_type of this RecoveryDBInstanceRequest.  # noqa: E501


        :return: The recovery_type of this RecoveryDBInstanceRequest.  # noqa: E501
        :rtype: str
        """
        return self._recovery_type

    @recovery_type.setter
    def recovery_type(self, recovery_type):
        """Sets the recovery_type of this RecoveryDBInstanceRequest.


        :param recovery_type: The recovery_type of this RecoveryDBInstanceRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["Instance"]  # noqa: E501
        if (self._configuration.client_side_validation and
                recovery_type not in allowed_values):
            raise ValueError(
                "Invalid value for `recovery_type` ({0}), must be one of {1}"  # noqa: E501
                .format(recovery_type, allowed_values)
            )

        self._recovery_type = recovery_type

    @property
    def restore_time(self):
        """Gets the restore_time of this RecoveryDBInstanceRequest.  # noqa: E501


        :return: The restore_time of this RecoveryDBInstanceRequest.  # noqa: E501
        :rtype: str
        """
        return self._restore_time

    @restore_time.setter
    def restore_time(self, restore_time):
        """Sets the restore_time of this RecoveryDBInstanceRequest.


        :param restore_time: The restore_time of this RecoveryDBInstanceRequest.  # noqa: E501
        :type: str
        """

        self._restore_time = restore_time

    @property
    def storage_space_gb(self):
        """Gets the storage_space_gb of this RecoveryDBInstanceRequest.  # noqa: E501


        :return: The storage_space_gb of this RecoveryDBInstanceRequest.  # noqa: E501
        :rtype: int
        """
        return self._storage_space_gb

    @storage_space_gb.setter
    def storage_space_gb(self, storage_space_gb):
        """Sets the storage_space_gb of this RecoveryDBInstanceRequest.


        :param storage_space_gb: The storage_space_gb of this RecoveryDBInstanceRequest.  # noqa: E501
        :type: int
        """

        self._storage_space_gb = storage_space_gb

    @property
    def storage_type(self):
        """Gets the storage_type of this RecoveryDBInstanceRequest.  # noqa: E501


        :return: The storage_type of this RecoveryDBInstanceRequest.  # noqa: E501
        :rtype: str
        """
        return self._storage_type

    @storage_type.setter
    def storage_type(self, storage_type):
        """Sets the storage_type of this RecoveryDBInstanceRequest.


        :param storage_type: The storage_type of this RecoveryDBInstanceRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["CloudStorage", "ESSDPL1", "ESSDPL2", "LocalSSD"]  # noqa: E501
        if (self._configuration.client_side_validation and
                storage_type not in allowed_values):
            raise ValueError(
                "Invalid value for `storage_type` ({0}), must be one of {1}"  # noqa: E501
                .format(storage_type, allowed_values)
            )

        self._storage_type = storage_type

    @property
    def used_time(self):
        """Gets the used_time of this RecoveryDBInstanceRequest.  # noqa: E501


        :return: The used_time of this RecoveryDBInstanceRequest.  # noqa: E501
        :rtype: int
        """
        return self._used_time

    @used_time.setter
    def used_time(self, used_time):
        """Sets the used_time of this RecoveryDBInstanceRequest.


        :param used_time: The used_time of this RecoveryDBInstanceRequest.  # noqa: E501
        :type: int
        """

        self._used_time = used_time

    @property
    def vpc_id(self):
        """Gets the vpc_id of this RecoveryDBInstanceRequest.  # noqa: E501


        :return: The vpc_id of this RecoveryDBInstanceRequest.  # noqa: E501
        :rtype: str
        """
        return self._vpc_id

    @vpc_id.setter
    def vpc_id(self, vpc_id):
        """Sets the vpc_id of this RecoveryDBInstanceRequest.


        :param vpc_id: The vpc_id of this RecoveryDBInstanceRequest.  # noqa: E501
        :type: str
        """

        self._vpc_id = vpc_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RecoveryDBInstanceRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RecoveryDBInstanceRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RecoveryDBInstanceRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    mongodb

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class CreateDBInstanceRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'auto_renew': 'bool',
        'charge_type': 'str',
        'count': 'int',
        'db_engine': 'str',
        'db_engine_version': 'str',
        'instance_name': 'str',
        'instance_type': 'str',
        'mongos_node_number': 'int',
        'mongos_node_spec': 'str',
        'node_number': 'int',
        'node_spec': 'str',
        'period': 'int',
        'period_unit': 'str',
        'project_name': 'str',
        'shard_number': 'int',
        'storage_space_gb': 'int',
        'subnet_id': 'str',
        'super_account_name': 'str',
        'super_account_password': 'str',
        'tags': 'list[TagForCreateDBInstanceInput]',
        'vpc_id': 'str',
        'zone_id': 'str'
    }

    attribute_map = {
        'auto_renew': 'AutoRenew',
        'charge_type': 'ChargeType',
        'count': 'Count',
        'db_engine': 'DBEngine',
        'db_engine_version': 'DBEngineVersion',
        'instance_name': 'InstanceName',
        'instance_type': 'InstanceType',
        'mongos_node_number': 'MongosNodeNumber',
        'mongos_node_spec': 'MongosNodeSpec',
        'node_number': 'NodeNumber',
        'node_spec': 'NodeSpec',
        'period': 'Period',
        'period_unit': 'PeriodUnit',
        'project_name': 'ProjectName',
        'shard_number': 'ShardNumber',
        'storage_space_gb': 'StorageSpaceGB',
        'subnet_id': 'SubnetId',
        'super_account_name': 'SuperAccountName',
        'super_account_password': 'SuperAccountPassword',
        'tags': 'Tags',
        'vpc_id': 'VpcId',
        'zone_id': 'ZoneId'
    }

    def __init__(self, auto_renew=None, charge_type=None, count=None, db_engine=None, db_engine_version=None, instance_name=None, instance_type=None, mongos_node_number=None, mongos_node_spec=None, node_number=None, node_spec=None, period=None, period_unit=None, project_name=None, shard_number=None, storage_space_gb=None, subnet_id=None, super_account_name=None, super_account_password=None, tags=None, vpc_id=None, zone_id=None, _configuration=None):  # noqa: E501
        """CreateDBInstanceRequest - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._auto_renew = None
        self._charge_type = None
        self._count = None
        self._db_engine = None
        self._db_engine_version = None
        self._instance_name = None
        self._instance_type = None
        self._mongos_node_number = None
        self._mongos_node_spec = None
        self._node_number = None
        self._node_spec = None
        self._period = None
        self._period_unit = None
        self._project_name = None
        self._shard_number = None
        self._storage_space_gb = None
        self._subnet_id = None
        self._super_account_name = None
        self._super_account_password = None
        self._tags = None
        self._vpc_id = None
        self._zone_id = None
        self.discriminator = None

        if auto_renew is not None:
            self.auto_renew = auto_renew
        if charge_type is not None:
            self.charge_type = charge_type
        if count is not None:
            self.count = count
        if db_engine is not None:
            self.db_engine = db_engine
        if db_engine_version is not None:
            self.db_engine_version = db_engine_version
        if instance_name is not None:
            self.instance_name = instance_name
        if instance_type is not None:
            self.instance_type = instance_type
        if mongos_node_number is not None:
            self.mongos_node_number = mongos_node_number
        if mongos_node_spec is not None:
            self.mongos_node_spec = mongos_node_spec
        if node_number is not None:
            self.node_number = node_number
        if node_spec is not None:
            self.node_spec = node_spec
        if period is not None:
            self.period = period
        if period_unit is not None:
            self.period_unit = period_unit
        if project_name is not None:
            self.project_name = project_name
        if shard_number is not None:
            self.shard_number = shard_number
        if storage_space_gb is not None:
            self.storage_space_gb = storage_space_gb
        if subnet_id is not None:
            self.subnet_id = subnet_id
        if super_account_name is not None:
            self.super_account_name = super_account_name
        if super_account_password is not None:
            self.super_account_password = super_account_password
        if tags is not None:
            self.tags = tags
        if vpc_id is not None:
            self.vpc_id = vpc_id
        if zone_id is not None:
            self.zone_id = zone_id

    @property
    def auto_renew(self):
        """Gets the auto_renew of this CreateDBInstanceRequest.  # noqa: E501


        :return: The auto_renew of this CreateDBInstanceRequest.  # noqa: E501
        :rtype: bool
        """
        return self._auto_renew

    @auto_renew.setter
    def auto_renew(self, auto_renew):
        """Sets the auto_renew of this CreateDBInstanceRequest.


        :param auto_renew: The auto_renew of this CreateDBInstanceRequest.  # noqa: E501
        :type: bool
        """

        self._auto_renew = auto_renew

    @property
    def charge_type(self):
        """Gets the charge_type of this CreateDBInstanceRequest.  # noqa: E501


        :return: The charge_type of this CreateDBInstanceRequest.  # noqa: E501
        :rtype: str
        """
        return self._charge_type

    @charge_type.setter
    def charge_type(self, charge_type):
        """Sets the charge_type of this CreateDBInstanceRequest.


        :param charge_type: The charge_type of this CreateDBInstanceRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["NotEnabled", "PostPaid", "Prepaid"]  # noqa: E501
        if (self._configuration.client_side_validation and
                charge_type not in allowed_values):
            raise ValueError(
                "Invalid value for `charge_type` ({0}), must be one of {1}"  # noqa: E501
                .format(charge_type, allowed_values)
            )

        self._charge_type = charge_type

    @property
    def count(self):
        """Gets the count of this CreateDBInstanceRequest.  # noqa: E501


        :return: The count of this CreateDBInstanceRequest.  # noqa: E501
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """Sets the count of this CreateDBInstanceRequest.


        :param count: The count of this CreateDBInstanceRequest.  # noqa: E501
        :type: int
        """

        self._count = count

    @property
    def db_engine(self):
        """Gets the db_engine of this CreateDBInstanceRequest.  # noqa: E501


        :return: The db_engine of this CreateDBInstanceRequest.  # noqa: E501
        :rtype: str
        """
        return self._db_engine

    @db_engine.setter
    def db_engine(self, db_engine):
        """Sets the db_engine of this CreateDBInstanceRequest.


        :param db_engine: The db_engine of this CreateDBInstanceRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["MongoDB"]  # noqa: E501
        if (self._configuration.client_side_validation and
                db_engine not in allowed_values):
            raise ValueError(
                "Invalid value for `db_engine` ({0}), must be one of {1}"  # noqa: E501
                .format(db_engine, allowed_values)
            )

        self._db_engine = db_engine

    @property
    def db_engine_version(self):
        """Gets the db_engine_version of this CreateDBInstanceRequest.  # noqa: E501


        :return: The db_engine_version of this CreateDBInstanceRequest.  # noqa: E501
        :rtype: str
        """
        return self._db_engine_version

    @db_engine_version.setter
    def db_engine_version(self, db_engine_version):
        """Sets the db_engine_version of this CreateDBInstanceRequest.


        :param db_engine_version: The db_engine_version of this CreateDBInstanceRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["MongoDB_4_0", "MongoDB_5_0"]  # noqa: E501
        if (self._configuration.client_side_validation and
                db_engine_version not in allowed_values):
            raise ValueError(
                "Invalid value for `db_engine_version` ({0}), must be one of {1}"  # noqa: E501
                .format(db_engine_version, allowed_values)
            )

        self._db_engine_version = db_engine_version

    @property
    def instance_name(self):
        """Gets the instance_name of this CreateDBInstanceRequest.  # noqa: E501


        :return: The instance_name of this CreateDBInstanceRequest.  # noqa: E501
        :rtype: str
        """
        return self._instance_name

    @instance_name.setter
    def instance_name(self, instance_name):
        """Sets the instance_name of this CreateDBInstanceRequest.


        :param instance_name: The instance_name of this CreateDBInstanceRequest.  # noqa: E501
        :type: str
        """
        if (self._configuration.client_side_validation and
                instance_name is not None and len(instance_name) > 64):
            raise ValueError("Invalid value for `instance_name`, length must be less than or equal to `64`")  # noqa: E501

        self._instance_name = instance_name

    @property
    def instance_type(self):
        """Gets the instance_type of this CreateDBInstanceRequest.  # noqa: E501


        :return: The instance_type of this CreateDBInstanceRequest.  # noqa: E501
        :rtype: str
        """
        return self._instance_type

    @instance_type.setter
    def instance_type(self, instance_type):
        """Sets the instance_type of this CreateDBInstanceRequest.


        :param instance_type: The instance_type of this CreateDBInstanceRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["ReplicaSet", "ShardedCluster"]  # noqa: E501
        if (self._configuration.client_side_validation and
                instance_type not in allowed_values):
            raise ValueError(
                "Invalid value for `instance_type` ({0}), must be one of {1}"  # noqa: E501
                .format(instance_type, allowed_values)
            )

        self._instance_type = instance_type

    @property
    def mongos_node_number(self):
        """Gets the mongos_node_number of this CreateDBInstanceRequest.  # noqa: E501


        :return: The mongos_node_number of this CreateDBInstanceRequest.  # noqa: E501
        :rtype: int
        """
        return self._mongos_node_number

    @mongos_node_number.setter
    def mongos_node_number(self, mongos_node_number):
        """Sets the mongos_node_number of this CreateDBInstanceRequest.


        :param mongos_node_number: The mongos_node_number of this CreateDBInstanceRequest.  # noqa: E501
        :type: int
        """

        self._mongos_node_number = mongos_node_number

    @property
    def mongos_node_spec(self):
        """Gets the mongos_node_spec of this CreateDBInstanceRequest.  # noqa: E501


        :return: The mongos_node_spec of this CreateDBInstanceRequest.  # noqa: E501
        :rtype: str
        """
        return self._mongos_node_spec

    @mongos_node_spec.setter
    def mongos_node_spec(self, mongos_node_spec):
        """Sets the mongos_node_spec of this CreateDBInstanceRequest.


        :param mongos_node_spec: The mongos_node_spec of this CreateDBInstanceRequest.  # noqa: E501
        :type: str
        """

        self._mongos_node_spec = mongos_node_spec

    @property
    def node_number(self):
        """Gets the node_number of this CreateDBInstanceRequest.  # noqa: E501


        :return: The node_number of this CreateDBInstanceRequest.  # noqa: E501
        :rtype: int
        """
        return self._node_number

    @node_number.setter
    def node_number(self, node_number):
        """Sets the node_number of this CreateDBInstanceRequest.


        :param node_number: The node_number of this CreateDBInstanceRequest.  # noqa: E501
        :type: int
        """

        self._node_number = node_number

    @property
    def node_spec(self):
        """Gets the node_spec of this CreateDBInstanceRequest.  # noqa: E501


        :return: The node_spec of this CreateDBInstanceRequest.  # noqa: E501
        :rtype: str
        """
        return self._node_spec

    @node_spec.setter
    def node_spec(self, node_spec):
        """Sets the node_spec of this CreateDBInstanceRequest.


        :param node_spec: The node_spec of this CreateDBInstanceRequest.  # noqa: E501
        :type: str
        """

        self._node_spec = node_spec

    @property
    def period(self):
        """Gets the period of this CreateDBInstanceRequest.  # noqa: E501


        :return: The period of this CreateDBInstanceRequest.  # noqa: E501
        :rtype: int
        """
        return self._period

    @period.setter
    def period(self, period):
        """Sets the period of this CreateDBInstanceRequest.


        :param period: The period of this CreateDBInstanceRequest.  # noqa: E501
        :type: int
        """

        self._period = period

    @property
    def period_unit(self):
        """Gets the period_unit of this CreateDBInstanceRequest.  # noqa: E501


        :return: The period_unit of this CreateDBInstanceRequest.  # noqa: E501
        :rtype: str
        """
        return self._period_unit

    @period_unit.setter
    def period_unit(self, period_unit):
        """Sets the period_unit of this CreateDBInstanceRequest.


        :param period_unit: The period_unit of this CreateDBInstanceRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["Month", "Year"]  # noqa: E501
        if (self._configuration.client_side_validation and
                period_unit not in allowed_values):
            raise ValueError(
                "Invalid value for `period_unit` ({0}), must be one of {1}"  # noqa: E501
                .format(period_unit, allowed_values)
            )

        self._period_unit = period_unit

    @property
    def project_name(self):
        """Gets the project_name of this CreateDBInstanceRequest.  # noqa: E501


        :return: The project_name of this CreateDBInstanceRequest.  # noqa: E501
        :rtype: str
        """
        return self._project_name

    @project_name.setter
    def project_name(self, project_name):
        """Sets the project_name of this CreateDBInstanceRequest.


        :param project_name: The project_name of this CreateDBInstanceRequest.  # noqa: E501
        :type: str
        """

        self._project_name = project_name

    @property
    def shard_number(self):
        """Gets the shard_number of this CreateDBInstanceRequest.  # noqa: E501


        :return: The shard_number of this CreateDBInstanceRequest.  # noqa: E501
        :rtype: int
        """
        return self._shard_number

    @shard_number.setter
    def shard_number(self, shard_number):
        """Sets the shard_number of this CreateDBInstanceRequest.


        :param shard_number: The shard_number of this CreateDBInstanceRequest.  # noqa: E501
        :type: int
        """

        self._shard_number = shard_number

    @property
    def storage_space_gb(self):
        """Gets the storage_space_gb of this CreateDBInstanceRequest.  # noqa: E501


        :return: The storage_space_gb of this CreateDBInstanceRequest.  # noqa: E501
        :rtype: int
        """
        return self._storage_space_gb

    @storage_space_gb.setter
    def storage_space_gb(self, storage_space_gb):
        """Sets the storage_space_gb of this CreateDBInstanceRequest.


        :param storage_space_gb: The storage_space_gb of this CreateDBInstanceRequest.  # noqa: E501
        :type: int
        """

        self._storage_space_gb = storage_space_gb

    @property
    def subnet_id(self):
        """Gets the subnet_id of this CreateDBInstanceRequest.  # noqa: E501


        :return: The subnet_id of this CreateDBInstanceRequest.  # noqa: E501
        :rtype: str
        """
        return self._subnet_id

    @subnet_id.setter
    def subnet_id(self, subnet_id):
        """Sets the subnet_id of this CreateDBInstanceRequest.


        :param subnet_id: The subnet_id of this CreateDBInstanceRequest.  # noqa: E501
        :type: str
        """

        self._subnet_id = subnet_id

    @property
    def super_account_name(self):
        """Gets the super_account_name of this CreateDBInstanceRequest.  # noqa: E501


        :return: The super_account_name of this CreateDBInstanceRequest.  # noqa: E501
        :rtype: str
        """
        return self._super_account_name

    @super_account_name.setter
    def super_account_name(self, super_account_name):
        """Sets the super_account_name of this CreateDBInstanceRequest.


        :param super_account_name: The super_account_name of this CreateDBInstanceRequest.  # noqa: E501
        :type: str
        """

        self._super_account_name = super_account_name

    @property
    def super_account_password(self):
        """Gets the super_account_password of this CreateDBInstanceRequest.  # noqa: E501


        :return: The super_account_password of this CreateDBInstanceRequest.  # noqa: E501
        :rtype: str
        """
        return self._super_account_password

    @super_account_password.setter
    def super_account_password(self, super_account_password):
        """Sets the super_account_password of this CreateDBInstanceRequest.


        :param super_account_password: The super_account_password of this CreateDBInstanceRequest.  # noqa: E501
        :type: str
        """

        self._super_account_password = super_account_password

    @property
    def tags(self):
        """Gets the tags of this CreateDBInstanceRequest.  # noqa: E501


        :return: The tags of this CreateDBInstanceRequest.  # noqa: E501
        :rtype: list[TagForCreateDBInstanceInput]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this CreateDBInstanceRequest.


        :param tags: The tags of this CreateDBInstanceRequest.  # noqa: E501
        :type: list[TagForCreateDBInstanceInput]
        """

        self._tags = tags

    @property
    def vpc_id(self):
        """Gets the vpc_id of this CreateDBInstanceRequest.  # noqa: E501


        :return: The vpc_id of this CreateDBInstanceRequest.  # noqa: E501
        :rtype: str
        """
        return self._vpc_id

    @vpc_id.setter
    def vpc_id(self, vpc_id):
        """Sets the vpc_id of this CreateDBInstanceRequest.


        :param vpc_id: The vpc_id of this CreateDBInstanceRequest.  # noqa: E501
        :type: str
        """

        self._vpc_id = vpc_id

    @property
    def zone_id(self):
        """Gets the zone_id of this CreateDBInstanceRequest.  # noqa: E501


        :return: The zone_id of this CreateDBInstanceRequest.  # noqa: E501
        :rtype: str
        """
        return self._zone_id

    @zone_id.setter
    def zone_id(self, zone_id):
        """Sets the zone_id of this CreateDBInstanceRequest.


        :param zone_id: The zone_id of this CreateDBInstanceRequest.  # noqa: E501
        :type: str
        """

        self._zone_id = zone_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CreateDBInstanceRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateDBInstanceRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateDBInstanceRequest):
            return True

        return self.to_dict() != other.to_dict()
